.. include:: readme.rst

.. toctree::
   :caption: Getting Started
   :maxdepth: 2

   Overview <readme>
   getting_started/concepts

.. toctree::
   :caption: Community
   :maxdepth: 2

   Community <community/welcome>
   Contributing <community/contributing>
   Annotations <community/annotations>
   Adapters <community/adapters>
   Custom Primitives <community/custom>

.. toctree::
   :caption: Resources
   :hidden:

   API Reference <api/mlprimitives>
   authors
   history


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
